@@ -7,5 +7,5 @@ utils::globalVariables(
       "value", ".model_desc", ".model_id",
       ".actual", ".calibration_data", ".prediction", ".ci",
       "yhat", ".model_desc_new", ".model_desc_old", ".model_desc_user",
-      ".model_table", ".model_table_clean", ".residuals", ".is_null")
+      ".model_table", ".model_table_clean", ".residuals", ".is_null", ".")
 )
